@@ -1,6 +1,6 @@
-from enum import Enum
 import time
-from typing import Any, Dict, List, Optional, Set, Tuple, Type, TypeVar, Union
+from enum import Enum
+from typing import Any, Dict, Iterable, Optional, Set, Tuple, Type, TypeVar, Union
 
 from meta_memcache.base.base_cache_pool import BaseCachePool
 from meta_memcache.configuration import LeasePolicy, RecachePolicy, StalePolicy
@@ -157,7 +157,7 @@ class CachePool(BaseCachePool):
 
             if isinstance(result, Value):
                 # It is a hit.
-                cas_token = result.int_flags.get(IntFlag.CAS_TOKEN)
+                cas_token = result.int_flags.get(IntFlag.RETURNED_CAS_TOKEN)
                 if Flag.WIN in result.flags:
                     # Win flag present, meaning we got the lease to
                     # recache/cache the item. We need to mimic a miss.
@@ -178,7 +178,7 @@ class CachePool(BaseCachePool):
             else:
                 # With MISS_LEASE_TTL we should always get a value
                 # because on miss a lease empty value is generated
-                raise MemcacheError("Unexpected response")
+                raise MemcacheError(f"Unexpected response: {result} for key {key}")
 
     # pyre-ignore[3]  Yeah, we return 'Any'
     def get(
@@ -195,7 +195,7 @@ class CachePool(BaseCachePool):
     # pyre-ignore[3]  Yeah, we return 'Any'
     def multi_get(
         self,
-        keys: List[Union[Key, str]],
+        keys: Iterable[Union[Key, str]],
         touch_ttl: Optional[int] = None,
         recache_policy: Optional[RecachePolicy] = None,
     ) -> Dict[Key, Optional[Any]]:
@@ -229,7 +229,7 @@ class CachePool(BaseCachePool):
             elif isinstance(result, Miss):
                 results[key] = None
             else:
-                raise MemcacheError("Unexpected response")
+                raise MemcacheError(f"Unexpected response: {result} for key {key}")
         return results
 
     # pyre-ignore[3]  Yeah, we return 'Any'
@@ -257,7 +257,7 @@ class CachePool(BaseCachePool):
         result = self.meta_get(key, flags=flags, int_flags=int_flags)
         if isinstance(result, Value):
             # It is a hit
-            cas_token = result.int_flags.get(IntFlag.CAS_TOKEN)
+            cas_token = result.int_flags.get(IntFlag.RETURNED_CAS_TOKEN)
             if Flag.WIN in result.flags:
                 # Win flag present, meaning we got the lease to
                 # recache the item. We need to mimic a miss.
@@ -267,7 +267,7 @@ class CachePool(BaseCachePool):
         elif isinstance(result, Miss):
             return None, None
         else:
-            raise MemcacheError("Unexpected response")
+            raise MemcacheError(f"Unexpected response: {result} for key {key}")
 
     def get_typed(
         self,
@@ -300,7 +300,7 @@ class CachePool(BaseCachePool):
 
         if not isinstance(value, cls):
             if error_on_type_mismatch:
-                raise ValueError(f"Expecting {cls} got {value}")
+                raise ValueError(f"Expecting {cls} got {value} for {key}")
             else:
                 value = None
         return value, cas_token
